using namespace RooFit ;

void ex7()
{
  // Make an empty workspace that exports its contents to CINT
  RooWorkspace *w = new RooWorkspace("w",kTRUE) ;  

  // Construct a probability _density_ model in an observable x in the data

  // The signal component is a Gaussian distribution peaked at 91 (mimicking a Z boson signal)
  w->factory("Gaussian::signal(x[90,0,120],mean[91],width[2])") ;
  // The background component is chosen flat for simplicity
  w->factory("Uniform:background(x)") ;
  // The expected signal yield is (again) the product of a floating mu and a fixed S
  w->factory("expr::Sexp('mu*S',mu[0,5],S[200])") ;
  // The complete model is the sum signal and background, each multiplied with the respective expected event count
  w->factory("SUM::model(Sexp*signal,B[20000]*background)") ;
  
  // Use RooFit toy sampler to generate data dataset with Sexp+B events
  RooDataSet* data = w->pdf("model")->generate(*w->var("x")) ;
   
  // Perform an (unbinned) maximum likelihood fit of the above model to the dataset 
  w->pdf("model")->fitTo(*data) ;

  // Plot the distribution of x, and overlay with the fitted model
  RooPlot* frame = w->var("x")->frame() ;
  data->plotOn(frame) ;
  w->pdf("model")->plotOn(frame) ;
  // To aid the interpretation, also overlay the background component of the model
  w->pdf("model")->plotOn(frame,Components("background"),LineStyle(kDashed)) ;


  frame->Draw() ;
}
