using namespace RooFit ;

void ex10sol()
{
  TFile* f = TFile::Open("ex10.root") ;
  TH1* h_sig = (TH1*) f->Get("h_sig") ;
  TH1* h_bkg = (TH1*) f->Get("h_bkg") ;
  TH1* h_data = (TH1*) f->Get("h_data") ;
  
  // Create a workspace with observable x[0,120]
  RooWorkspace w("w") ;
  w.factory("x[20,120]") ;

  // Tie TF1 h_sig to observable x in RooFit binned dataset dh_sig
  RooDataHist dh_sig("dh_sig","dh_sig",*w.var("x"),h_sig) ;
  RooDataHist dh_bkg("dh_bkg","dh_bkg",*w.var("x"),h_bkg) ;
  RooDataHist data("data","data",*w.var("x"),h_data) ;

  // Import both datasets in the workspace
  w.import(dh_sig) ;
  w.import(dh_bkg) ;
  
  w.factory("HistFunc::hf_sig(x,dh_sig)") ;
  w.factory("HistFunc::hf_bkg(x,dh_bkg)") ;

  w.factory("ASUM::model(mu[1,0,5]*hf_sig,nu[1]*hf_bkg)") ;

  w.pdf("model")->fitTo(data) ;
  
  cout << "Nexpected = " << w.pdf("model")->expectedEvents(*w.var("x")) << endl ;
  
  RooPlot* frame = w.var("x")->frame();
  data.plotOn(frame) ;
  w.pdf("model")->plotOn(frame) ;
  w.pdf("model")->plotOn(frame,Components("hf_bkg"),LineStyle(kDashed)) ;
  frame->Draw() ;
}
