using namespace RooFit ;

void ex11sol()
{
  gSystem->Load("libRooFit") ;

  gROOT->ProcessLine(".L code/RooParamHistFunc2.cxx+") ;
  gROOT->ProcessLine(".L code/RooHistConstraint2.cxx+") ;

  TFile* f = TFile::Open("ex11.root") ;
  TH1* h_sig = (TH1*) f->Get("h_sig") ;
  TH1* h_bkg = (TH1*) f->Get("h_bkg") ;
  TH1* h_data = (TH1*) f->Get("h_data") ;
  TH1* h_data_small = (TH1*) f->Get("h_data_small") ;
  TH1* h_data_large = (TH1*) f->Get("h_data_large") ;
  
  // Create a workspace with observable x[0,120]
  RooWorkspace w("w") ;
  w.factory("x[20,120]") ;
  w.var("x")->setBins(20) ;
  
  // Tie TF1 h_sig to observable x in RooFit binned dataset dh_sig
  RooDataHist dh_sig("dh_sig","dh_sig",*w.var("x"),h_sig) ;
  RooDataHist dh_bkg("dh_bkg","dh_bkg",*w.var("x"),h_bkg) ;
  RooDataHist data("data","data",*w.var("x"),h_data) ;
  RooDataHist data_small("data_small","data_small",*w.var("x"),h_data_small) ;
  RooDataHist data_large("data_large","data_large",*w.var("x"),h_data_large) ;

  // Import both datasets in the workspace
  w.import(dh_sig) ;
  w.import(dh_bkg) ;
  
  w.factory("ParamHistFunc2::hf_sig(dh_sig)") ;
  w.factory("ParamHistFunc2::hf_bkg(dh_bkg)") ;

  w.factory("ASUM::model(prod(mu[1,0,5],binw[0.2],SF[10])*hf_sig,prod(nu[1],binw,SF)*hf_bkg)") ;
  w.factory("PROD::model2(model|~x,HistConstraint2::hc_sig(hf_sig),HistConstraint2::hc_bkg(hf_bkg))") ;
  
  w.pdf("model2")->fitTo(data_large) ;
    
  RooPlot* frame = w.var("x")->frame();
  data_small.plotOn(frame) ;
  w.pdf("model")->plotOn(frame) ;
  w.pdf("model")->plotOn(frame,Components("hf_bkg"),LineStyle(kDashed)) ;
  frame->Draw() ;
}
