using namespace RooFit ;

void ex13sol()
{
  gSystem->Load("libRooFit") ;


  TFile* f = TFile::Open("ex13.root") ;
  TH1* h_sig_wup = (TH1*) f->Get("h_sig_wup") ;
  TH1* h_sig_up = (TH1*) f->Get("h_sig_up") ;
  TH1* h_sig    = (TH1*) f->Get("h_sig") ;
  TH1* h_sig_dn = (TH1*) f->Get("h_sig_dn") ;
  TH1* h_sig_wdn = (TH1*) f->Get("h_sig_wdn") ;
  TH1* h_bkg    = (TH1*) f->Get("h_bkg") ;
  TH1* h_data   = (TH1*) f->Get("h_data") ;
  
  // Create a workspace with observable x[0,120]
  RooWorkspace w("w") ;
  w.factory("x[20,120]") ;  
  
  // Tie TF1 h_sig to observable x in RooFit binned dataset dh_sig
  RooDataHist dh_sig_wup("dh_sig_wup","dh_sig_wup",*w.var("x"),h_sig_wup) ;
  RooDataHist dh_sig_up("dh_sig_up","dh_sig_up",*w.var("x"),h_sig_up) ;
  RooDataHist    dh_sig("dh_sig"   ,"dh_sig"   ,*w.var("x"),h_sig) ;
  RooDataHist dh_sig_dn("dh_sig_dn","dh_sig_dn",*w.var("x"),h_sig_dn) ;
  RooDataHist dh_sig_wdn("dh_sig_wdn","dh_sig_wdn",*w.var("x"),h_sig_wdn) ;
  RooDataHist dh_bkg("dh_bkg","dh_bkg",*w.var("x"),h_bkg) ;

  RooDataHist data("data","data",*w.var("x"),h_data) ;

  // Import both datasets in the workspace
  w.import(dh_sig_wup) ;
  w.import(dh_sig_up) ;
  w.import(dh_sig) ;
  w.import(dh_sig_dn) ;
  w.import(dh_sig_wdn) ;
  w.import(dh_bkg) ;
  
  w.factory("HistFunc::hf_sig_up(x,dh_sig_up)") ;
  w.factory("HistFunc::hf_sig(x,dh_sig)") ;
  w.factory("HistFunc::hf_sig_dn(x,dh_sig_dn)") ;
  w.factory("HistFunc::hf_sig_wup(x,dh_sig_wup)") ;
  w.factory("HistFunc::hf_sig_wdn(x,dh_sig_wdn)") ;
  w.factory("PiecewiseInterpolation::pi_sig(hf_sig,{hf_sig_dn,hf_sig_wdn},{hf_sig_up,hf_sig_wup},{alpha[-3,3],beta[-3,3]})") ;
  ((PiecewiseInterpolation*)w.function("pi_sig"))->setPositiveDefinite(kTRUE) ;
  ((PiecewiseInterpolation*)w.function("pi_sig"))->setAllInterpCodes(0) ;

  w.factory("HistFunc::hf_bkg(x,dh_bkg)") ;

  w.factory("ASUM::model(prod(mu[1,0,5],binw[1])*pi_sig,prod(nu[1],binw)*hf_bkg)") ;
  w.factory("PROD::model2(model,Gaussian(0,alpha,1),Gaussian(0,beta,1))") ;
  
  w.pdf("model2")->fitTo(data) ;
    
  RooPlot* frame = w.var("x")->frame();
  data.plotOn(frame) ;
  w.pdf("model2")->plotOn(frame) ;
  w.pdf("model2")->plotOn(frame,Components("hf_bkg"),LineStyle(kDashed)) ;
  frame->Draw() ;


}
