using namespace RooFit ;

void ex14sol()
{
  gSystem->Load("libRooFit") ;

  gROOT->ProcessLine(".L code/RooParamHistFunc2.cxx+") ;
  gROOT->ProcessLine(".L code/RooHistConstraint2.cxx+") ;

  TFile* f = TFile::Open("ex14.root") ;
  TH1* h_sig_up = (TH1*) f->Get("h_sig_up") ;
  TH1* h_sig    = (TH1*) f->Get("h_sig") ;
  TH1* h_sig_dn = (TH1*) f->Get("h_sig_dn") ;
  TH1* h_bkg    = (TH1*) f->Get("h_bkg") ;
  TH1* h_data   = (TH1*) f->Get("h_data") ;
  
  // Create a workspace with observable x[0,120]
  RooWorkspace w("w") ;
  w.factory("x[20,120]") ;
  w.var("x")->setBins(20) ;
  
  // Tie TF1 h_sig to observable x in RooFit binned dataset dh_sig
  RooDataHist dh_sig_up("dh_sig_up","dh_sig_up",*w.var("x"),h_sig_up) ;
  RooDataHist    dh_sig("dh_sig"   ,"dh_sig"   ,*w.var("x"),h_sig) ;
  RooDataHist dh_sig_dn("dh_sig_dn","dh_sig_dn",*w.var("x"),h_sig_dn) ;
  RooDataHist dh_bkg("dh_bkg","dh_bkg",*w.var("x"),h_bkg) ;

  RooDataHist data("data","data",*w.var("x"),h_data) ;

  // Import both datasets in the workspace
  w.import(dh_sig_up) ;
  w.import(dh_sig) ;
  w.import(dh_sig_dn) ;
  w.import(dh_bkg) ;
  
  w.factory("HistFunc::hf_sig_up(x,dh_sig_up)") ;
  w.factory("ParamHistFunc2::hf_sig(dh_sig)") ;
  w.factory("HistFunc::hf_sig_dn(x,dh_sig_dn)") ;
  w.factory("PiecewiseInterpolation::pi_sig(hf_sig,hf_sig_dn,hf_sig_up,alpha[-1,1])") ;
  ((PiecewiseInterpolation*)w.function("pi_sig"))->setPositiveDefinite(kTRUE) ;
  ((PiecewiseInterpolation*)w.function("pi_sig"))->setAllInterpCodes(4) ;

  w.factory("ParamHistFunc2::hf_bkg(dh_bkg)") ;

  w.factory("ASUM::model(prod(mu[1,0,5],binw[0.2])*pi_sig,prod(nu[1],binw)*hf_bkg)") ;
  w.factory("PROD::model2(model,Gaussian(0,alpha,1),HistConstraint2(hf_bkg),HistConstraint2(hf_sig))") ;
  
  w.pdf("model2")->fitTo(data) ;
    
  RooPlot* frame = w.var("x")->frame();
  data.plotOn(frame) ;
  w.pdf("model2")->plotOn(frame) ;
  w.pdf("model2")->plotOn(frame,Components("hf_bkg"),LineStyle(kDashed)) ;
  frame->Draw() ;

}
