using namespace RooFit ;

void ex2sol()
{
  // Make an empty workspace that exports its contents to CINT
  RooWorkspace *w = new RooWorkspace("w") ;  

  // This constructs the same model as ex1.
  w->factory("S[0,-3,100]") ;
  w->factory("B[5]") ;       
  w->factory("N[0,100]") ;
  w->factory("expr::Nexp('S+B',S,B)") ;  
  w->factory("Poisson::model(N,Nexp)") ;

  // Now we construct a 'dataset' which in this case
  // contains a single measurement value N=7

  RooDataSet data("data","data",*w->var("N")) ;
  w->var("N")->setVal(7) ;
  data.add(*w->var("N")) ; // adds current value of N as 'event' to dataset

  // Now we can construct ( the -log of) the likelihood
  RooAbsReal* nll = w->pdf("model")->createNLL(data) ;

  // Now we plot -logL vs the (floating) model parameter S
  RooPlot* frame = w->var("S")->frame(-3,10) ;
  nll->plotOn(frame) ;

  frame->Draw() ;

  // Now we minimize the likelihood w.r.t S using Minuit
  RooMinimizer m(*nll) ;
  m.migrad() ;
  m.hesse() ;
  m.minos() ;

  
  // Now we create a second dataset with a larger N
  RooDataSet data2("data2","data2",*w->var("N")) ;
  w->var("N")->setVal(10) ;
  data2.add(*w->var("N")) ; // adds current value of N as 'event' to dataset


  // Instead of creating the likelihood 'by hand' we can 
  // now do the 'shortcut' procedure - we perform a 'fit'
  // [ which really means that you create the likelihood
  //  (as before), minimize it, and then throw it away again
  // but save the parameter value that correspond to
  // the best-fit in S
  
  w->pdf("model")->fitTo(data2,Minos(kTRUE)) ;
  
  
}
